{% extends "comments/base.html" %}
{% load i18n %}

{% block title %}{% trans "Edit your comment" %}{% endblock %}

{% block content %}
    {% load comments_extension %}
        <form action="{% comment_edit_form_target comment_obj %}" method="post">{% csrf_token %}
        {% if next %}<div><input type="hidden" name="next" value="{{ next }}" /></div>{% endif %}
        {% if form.errors %}
            <h1>{% blocktrans count counter=form.errors|length %}Please correct the error below{% plural %}Please correct the errors below{% endblocktrans %}</h1>
        {% else %}
            <h1>{% trans "Edit your comment" %}</h1>
            <p><blockquote>{{ comment_obj|linebreaks }}</blockquote></p>
        {% endif %}
        {% for field in form %}
            {% if field.is_hidden %}
                <div>{{ field }}</div>
            {% else %}
                {% if field.errors %}{{ field.errors }}{% endif %}
                <p
                    {% if field.errors %} class="error"{% endif %}
                    {% ifequal field.name "honeypot" %} style="display:none;"{% endifequal %}>
                    {{ field.label_tag }} {{ field }}
                </p>
            {% endif %}
        {% endfor %}
        <p class="submit">
            <input type="submit" name="submit" class="submit-post" value="{% trans "Save" %}" />
            <input type="submit" name="preview" class="submit-preview" value="{% trans "Preview" %}" />
        </p>
      </form>
{% endblock %}
